@@ -95,6 +95,7 @@ MainWindow::MainWindow(QWidget* parent)
     m_isWayland = QGuiApplication::platformName().startsWith(QLatin1String("wayland"));
 #if HAVE_KWAYLAND
     m_plasmaShell = Q_NULLPTR;
+    m_plasmaShellSurface = Q_NULLPTR;
     initWayland();
 #endif
 
@@ -118,6 +119,8 @@ MainWindow::MainWindow(QWidget* parent)
     connect(m_sessionStack, SIGNAL(sessionRemoved(int)), m_tabBar, SLOT(removeTab(int)));
     connect(m_sessionStack, SIGNAL(activeTitleChanged(QString)),
         m_titleBar, SLOT(setTitle(QString)));
+    connect(m_sessionStack, SIGNAL(activeTitleChanged(QString)),
+        this, SLOT(setWindowTitle(QString)));
 
     connect(&m_mousePoller, SIGNAL(timeout()), this, SLOT(pollMouse()));
 
@@ -176,6 +179,21 @@ void MainWindow::initWayland()
     registry->setup();
     connection->roundtrip();
 }
+
+void MainWindow::initWaylandSurface()
+{
+    if (m_plasmaShellSurface) {
+        return;
+    }
+    if (!m_plasmaShell) {
+        return;
+    }
+    if (auto surface = KWayland::Client::Surface::fromWindow(windowHandle())) {
+        m_plasmaShellSurface = m_plasmaShell->createSurface(surface, this);
+        m_plasmaShellSurface->setPosition(pos());
+    }
+}
+
 #endif
 
 bool MainWindow::queryClose()
@@ -861,13 +879,7 @@ void MainWindow::setWindowGeometry(int newWidth, int newHeight, int newPosition)
     setGeometry(workArea.x() + workArea.width() * newPosition * (100 - newWidth) / 10000,
                 workArea.y(), targetWidth, maxHeight);
 #if HAVE_KWAYLAND
-    if (m_plasmaShell) {
-        if (auto surface = KWayland::Client::Surface::fromWindow(windowHandle())) {
-            if (auto plasmaSurface = m_plasmaShell->createSurface(surface, this)) {
-                plasmaSurface->setPosition(pos());
-            }
-        }
-    }
+    initWaylandSurface();
 #endif
 
     maxHeight -= m_titleBar->height();
@@ -1013,8 +1025,15 @@ void MainWindow::wmActiveWindowChanged()
         return;
     }
 
-    if (!Settings::keepOpen() && isVisible() && KWindowSystem::activeWindow() != winId()) {
-        toggleWindowState();
+
+    if (m_isX11) {
+        if (!Settings::keepOpen() && isVisible() && KWindowSystem::activeWindow() != winId()) {
+            toggleWindowState();
+        }
+    } else {
+        if (!Settings::keepOpen() && hasFocus()) {
+            toggleWindowState();
+        }
     }
 }
 
@@ -1303,6 +1322,10 @@ void MainWindow::sharedAfterOpenWindow()
 
     applyWindowProperties();
 
+#if HAVE_KWAYLAND
+    initWaylandSurface();
+#endif
+
     emit windowOpened();
 }
 
@@ -1316,6 +1339,11 @@ void MainWindow::sharedAfterHideWindow()
 {
     if (Settings::pollMouse()) toggleMousePoll(true);
 
+#if HAVE_KWAYLAND
+    delete m_plasmaShellSurface;
+    m_plasmaShellSurface = Q_NULLPTR;
+#endif
+
     emit windowClosed();
 }
 
