@@ -29,10 +29,10 @@
 #include <KPluginFactory>
 #include <KPluginLoader>
 #include <KService>
-#include <KUser>
 
 #include <QAction>
 #include <QApplication>
+#include <QDir>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QWidget>
@@ -86,7 +86,7 @@ Terminal::Terminal(QWidget* parent) : QObject(parent)
         disableOffendingPartActions();
 
         m_terminalInterface = qobject_cast<TerminalInterface*>(m_part);
-        if (m_terminalInterface) m_terminalInterface->showShellInDir(KUser().homeDir());
+        if (m_terminalInterface) m_terminalInterface->showShellInDir(QDir::homePath());
     }
     else
         displayKPartLoadError();
